Improve this doc View Source

## Usage

`$compileProvider();`

## Methods

- ###

  `directive(name, directiveFactory);`

  Register a new directive with the compiler.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  name | stringObject | Name of the directive in camel-case (i.e. `ngBind` which will match as `ng-bind`), or an object map of directives where the keys are the names and the values are the factories.
  directiveFactory | function()Array | An injectable directive factory function. See directive for more info.

  #### Returns

  ng.$compileProvider | Self for chaining.

- ###

  `aHrefSanitizationWhitelist([regexp]);`

  Retrieves or overrides the default regular expression that is used for whitelisting of safe urls during a[href] sanitization.

  The sanitization is a security measure aimed at prevent XSS attacks via html links.

  Any url about to be assigned to a[href] via data-binding is first normalized and turned into an absolute url. Afterwards, the url is matched against the `aHrefSanitizationWhitelist` regular expression. If a match is found, the original url is written into the dom. Otherwise, the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  regexp (optional) | RegExp | New regexp to whitelist urls with.

  #### Returns

  RegExpng.$compileProvider | Current RegExp if called without value or self for chaining otherwise.

- ###

  `imgSrcSanitizationWhitelist([regexp]);`

  Retrieves or overrides the default regular expression that is used for whitelisting of safe urls during img[src] sanitization.

  The sanitization is a security measure aimed at prevent XSS attacks via html links.

  Any url about to be assigned to img[src] via data-binding is first normalized and turned into an absolute url. Afterwards, the url is matched against the `imgSrcSanitizationWhitelist` regular expression. If a match is found, the original url is written into the dom. Otherwise, the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  regexp (optional) | RegExp | New regexp to whitelist urls with.

  #### Returns

  RegExpng.$compileProvider | Current RegExp if called without value or self for chaining otherwise.